# Discotime: Discrete-time Competing Risks Models with PyTorch Lightning

[**Docs**](https://optuna.readthedocs.io/en/stable/)
| [**Installation**](https://optuna.readthedocs.io/en/stable/installation.html)
| [**Tutorial**](https://optuna.readthedocs.io/en/stable/tutorial/index.html)
| [**Examples**](https://github.com/optuna/optuna-examples)

*Discotime* is a python package for discrete-time survival analysis 
with neural networks that have been designed to handle competing risk models.
The package relies on PyTorch Lightning to provide an easy-to-use interface,
that still can be customized to your heart's content. 
The packages contains an implementation of discrete time-to-event models
for neural networks (using PyTorch), different evaluation metrics,
and a couple of different competing risk datasets. 
**The package is currently under development,**
**Breaking changes are to be expected.**

